AgentHarnessException class sealed

Base class for all harness exceptions. Sealed so consumers can exhaustively switch on the exception type.

Implemented types
Implementers

Properties

cause Object?
The original error that caused this exception, if any.
final
causeStack StackTrace?
The stack trace of the original error, if any.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of what went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited